@@ -9,7 +9,7 @@ from .utils import *
 from .runner_cluster import ClusterRunner
 from .runner_propensity import PropensityRunner
 from .runner_regression import RegressionRunner
-from .runner_psm import PropensityScoreMatchingRunner
+from .runner_causal import CausalRunner
 from .runner_task import TaskRunner
 
 
@@ -37,7 +37,7 @@ class Analyzer:
         self.cluster = ClusterRunner(client=self.__client, base_url=self.__base_url)
         self.propensity = PropensityRunner(client=self.__client, base_url=self.__base_url)
         self.regression = RegressionRunner(client=self.__client, base_url=self.__base_url)
-        self.psm = PropensityScoreMatchingRunner(client=self.__client, base_url=self.__base_url)
+        self.causal = CausalRunner(client=self.__client, base_url=self.__base_url)
         return
 
     def version(self):
